pub fn bytes(code: EncodedInst) -> StringExpand description
One encoded instruction’s sixteen bytes, in hex, low byte first.
The order the bytes are stored in rather than the order a number reads in, because what a reader of this is checking is a byte offset.